==> openshift-model-4.11.2-sources.jar: io/fabric8/openshift/api/model/ClusterVersionSpecFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface ClusterVersionSpecFluent<A extends ClusterVersionSpecFluent<A>> extends Fluent<A>{


    public String getChannel();
    public A withChannel(String channel);
    public Boolean hasChannel();
    public A withNewChannel(String arg1);
    public A withNewChannel(StringBuilder arg1);
    public A withNewChannel(StringBuffer arg1);
    public String getClusterID();
    public A withClusterID(String clusterID);
    public Boolean hasClusterID();
    public A withNewClusterID(String arg1);
    public A withNewClusterID(StringBuilder arg1);
    public A withNewClusterID(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildDesiredUpdate instead.
 * @return The buildable object.
 */
@Deprecated public Update getDesiredUpdate();
    public Update buildDesiredUpdate();
    public A withDesiredUpdate(Update desiredUpdate);
    public Boolean hasDesiredUpdate();
    public A withNewDesiredUpdate(Boolean force,String image,String version);
    public ClusterVersionSpecFluent.DesiredUpdateNested<A> withNewDesiredUpdate();
    public ClusterVersionSpecFluent.DesiredUpdateNested<A> withNewDesiredUpdateLike(Update item);
    public ClusterVersionSpecFluent.DesiredUpdateNested<A> editDesiredUpdate();
    public ClusterVersionSpecFluent.DesiredUpdateNested<A> editOrNewDesiredUpdate();
    public ClusterVersionSpecFluent.DesiredUpdateNested<A> editOrNewDesiredUpdateLike(Update item);
    public A addToOverrides(int index,ComponentOverride item);
    public A setToOverrides(int index,ComponentOverride item);
    public A addToOverrides(ComponentOverride... items);
    public A addAllToOverrides(Collection<ComponentOverride> items);
    public A removeFromOverrides(ComponentOverride... items);
    public A removeAllFromOverrides(Collection<ComponentOverride> items);
    public A removeMatchingFromOverrides(io.fabric8.kubernetes.api.builder.Predicate<ComponentOverrideBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildOverrides instead.
 * @return The buildable object.
 */
@Deprecated public List<ComponentOverride> getOverrides();
    public List<ComponentOverride> buildOverrides();
    public ComponentOverride buildOverride(int index);
    public ComponentOverride buildFirstOverride();
    public ComponentOverride buildLastOverride();
    public ComponentOverride buildMatchingOverride(io.fabric8.kubernetes.api.builder.Predicate<ComponentOverrideBuilder> predicate);
    public Boolean hasMatchingOverride(io.fabric8.kubernetes.api.builder.Predicate<ComponentOverrideBuilder> predicate);
    public A withOverrides(List<ComponentOverride> overrides);
    public A withOverrides(ComponentOverride... overrides);
    public Boolean hasOverrides();
    public A addNewOverride(String group,String kind,String name,String namespace,Boolean unmanaged);
    public ClusterVersionSpecFluent.OverridesNested<A> addNewOverride();
    public ClusterVersionSpecFluent.OverridesNested<A> addNewOverrideLike(ComponentOverride item);
    public ClusterVersionSpecFluent.OverridesNested<A> setNewOverrideLike(int index,ComponentOverride item);
    public ClusterVersionSpecFluent.OverridesNested<A> editOverride(int index);
    public ClusterVersionSpecFluent.OverridesNested<A> editFirstOverride();
    public ClusterVersionSpecFluent.OverridesNested<A> editLastOverride();
    public ClusterVersionSpecFluent.OverridesNested<A> editMatchingOverride(io.fabric8.kubernetes.api.builder.Predicate<ComponentOverrideBuilder> predicate);
    public String getUpstream();
    public A withUpstream(String upstream);
    public Boolean hasUpstream();
    public A withNewUpstream(String arg1);
    public A withNewUpstream(StringBuilder arg1);
    public A withNewUpstream(StringBuffer arg1);

    public interface DesiredUpdateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,UpdateFluent<ClusterVersionSpecFluent.DesiredUpdateNested<N>>{

        
    public N and();    public N endDesiredUpdate();
}
    public interface OverridesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ComponentOverrideFluent<ClusterVersionSpecFluent.OverridesNested<N>>{

        
    public N and();    public N endOverride();
}


}

==> openshift-model-5.0.3-sources.jar: io/fabric8/openshift/api/model/ClusterVersionSpecFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface ClusterVersionSpecFluent<A extends ClusterVersionSpecFluent<A>> extends Fluent<A> {


    public String getChannel();
    public A withChannel(String channel);
    public Boolean hasChannel();
    public A withNewChannel(String arg1);
    public A withNewChannel(StringBuilder arg1);
    public A withNewChannel(StringBuffer arg1);
    public String getClusterID();
    public A withClusterID(String clusterID);
    public Boolean hasClusterID();
    public A withNewClusterID(String arg1);
    public A withNewClusterID(StringBuilder arg1);
    public A withNewClusterID(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildDesiredUpdate instead.
 * @return The buildable object.
 */
@Deprecated public Update getDesiredUpdate();
    public Update buildDesiredUpdate();
    public A withDesiredUpdate(Update desiredUpdate);
    public Boolean hasDesiredUpdate();
    public A withNewDesiredUpdate(Boolean force,String image,String version);
    public ClusterVersionSpecFluent.DesiredUpdateNested<A> withNewDesiredUpdate();
    public ClusterVersionSpecFluent.DesiredUpdateNested<A> withNewDesiredUpdateLike(Update item);
    public ClusterVersionSpecFluent.DesiredUpdateNested<A> editDesiredUpdate();
    public ClusterVersionSpecFluent.DesiredUpdateNested<A> editOrNewDesiredUpdate();
    public ClusterVersionSpecFluent.DesiredUpdateNested<A> editOrNewDesiredUpdateLike(Update item);
    public A addToOverrides(int index,ComponentOverride item);
    public A setToOverrides(int index,ComponentOverride item);
    public A addToOverrides(ComponentOverride... items);
    public A addAllToOverrides(Collection<ComponentOverride> items);
    public A removeFromOverrides(ComponentOverride... items);
    public A removeAllFromOverrides(Collection<ComponentOverride> items);
    public A removeMatchingFromOverrides(Predicate<ComponentOverrideBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildOverrides instead.
 * @return The buildable object.
 */
@Deprecated public List<ComponentOverride> getOverrides();
    public List<ComponentOverride> buildOverrides();
    public ComponentOverride buildOverride(int index);
    public ComponentOverride buildFirstOverride();
    public ComponentOverride buildLastOverride();
    public ComponentOverride buildMatchingOverride(Predicate<ComponentOverrideBuilder> predicate);
    public Boolean hasMatchingOverride(Predicate<ComponentOverrideBuilder> predicate);
    public A withOverrides(List<ComponentOverride> overrides);
    public A withOverrides(ComponentOverride... overrides);
    public Boolean hasOverrides();
    public A addNewOverride(String group,String kind,String name,String namespace,Boolean unmanaged);
    public ClusterVersionSpecFluent.OverridesNested<A> addNewOverride();
    public ClusterVersionSpecFluent.OverridesNested<A> addNewOverrideLike(ComponentOverride item);
    public ClusterVersionSpecFluent.OverridesNested<A> setNewOverrideLike(int index,ComponentOverride item);
    public ClusterVersionSpecFluent.OverridesNested<A> editOverride(int index);
    public ClusterVersionSpecFluent.OverridesNested<A> editFirstOverride();
    public ClusterVersionSpecFluent.OverridesNested<A> editLastOverride();
    public ClusterVersionSpecFluent.OverridesNested<A> editMatchingOverride(Predicate<ComponentOverrideBuilder> predicate);
    public String getUpstream();
    public A withUpstream(String upstream);
    public Boolean hasUpstream();
    public A withNewUpstream(String arg1);
    public A withNewUpstream(StringBuilder arg1);
    public A withNewUpstream(StringBuffer arg1);
    public interface DesiredUpdateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,UpdateFluent<ClusterVersionSpecFluent.DesiredUpdateNested<N>> {

            public N and();
            public N endDesiredUpdate();    }


    public interface OverridesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ComponentOverrideFluent<ClusterVersionSpecFluent.OverridesNested<N>> {

            public N and();
            public N endOverride();    }


}
